proto

package module
v0.0.0-...-82892ca Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: MIT Imports: 9 Imported by: 1

Documentation

Index

Constants

const (
	TmpAccess_GenerateTmpToken_FullMethodName = "/proto.TmpAccess/GenerateTmpToken"
)

Variables

var File_proto_tmpaccess_proto protoreflect.FileDescriptor
var TmpAccess_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "proto.TmpAccess",
	HandlerType: (*TmpAccessServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GenerateTmpToken",
			Handler:    _TmpAccess_GenerateTmpToken_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "proto/tmpaccess.proto",
}

TmpAccess_ServiceDesc is the grpc.ServiceDesc for TmpAccess service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterTmpAccessServer

func RegisterTmpAccessServer(s grpc.ServiceRegistrar, srv TmpAccessServer)

Types

type GenerateTmpTokenRequest

type GenerateTmpTokenRequest struct {
	Payload    map[string]string `` /* 141-byte string literal not displayed */
	TtlSeconds int64             `protobuf:"varint,2,opt,name=ttl_seconds,json=ttlSeconds,proto3" json:"ttl_seconds,omitempty"`
	// contains filtered or unexported fields
}

func (*GenerateTmpTokenRequest) Descriptor deprecated

func (*GenerateTmpTokenRequest) Descriptor() ([]byte, []int)

Deprecated: Use GenerateTmpTokenRequest.ProtoReflect.Descriptor instead.

func (*GenerateTmpTokenRequest) GetPayload

func (x *GenerateTmpTokenRequest) GetPayload() map[string]string

func (*GenerateTmpTokenRequest) GetTtlSeconds

func (x *GenerateTmpTokenRequest) GetTtlSeconds() int64

func (*GenerateTmpTokenRequest) ProtoMessage

func (*GenerateTmpTokenRequest) ProtoMessage()

func (*GenerateTmpTokenRequest) ProtoReflect

func (x *GenerateTmpTokenRequest) ProtoReflect() protoreflect.Message

func (*GenerateTmpTokenRequest) Reset

func (x *GenerateTmpTokenRequest) Reset()

func (*GenerateTmpTokenRequest) String

func (x *GenerateTmpTokenRequest) String() string

type GenerateTmpTokenResponse

type GenerateTmpTokenResponse struct {
	Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
	// contains filtered or unexported fields
}

func (*GenerateTmpTokenResponse) Descriptor deprecated

func (*GenerateTmpTokenResponse) Descriptor() ([]byte, []int)

Deprecated: Use GenerateTmpTokenResponse.ProtoReflect.Descriptor instead.

func (*GenerateTmpTokenResponse) GetToken

func (x *GenerateTmpTokenResponse) GetToken() string

func (*GenerateTmpTokenResponse) ProtoMessage

func (*GenerateTmpTokenResponse) ProtoMessage()

func (*GenerateTmpTokenResponse) ProtoReflect

func (x *GenerateTmpTokenResponse) ProtoReflect() protoreflect.Message

func (*GenerateTmpTokenResponse) Reset

func (x *GenerateTmpTokenResponse) Reset()

func (*GenerateTmpTokenResponse) String

func (x *GenerateTmpTokenResponse) String() string

type TmpAccessClient

type TmpAccessClient interface {
	GenerateTmpToken(ctx context.Context, in *GenerateTmpTokenRequest, opts ...grpc.CallOption) (*GenerateTmpTokenResponse, error)
}

TmpAccessClient is the client API for TmpAccess service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewTmpAccessClient

func NewTmpAccessClient(cc grpc.ClientConnInterface) TmpAccessClient

type TmpAccessServer

type TmpAccessServer interface {
	GenerateTmpToken(context.Context, *GenerateTmpTokenRequest) (*GenerateTmpTokenResponse, error)
	// contains filtered or unexported methods
}

TmpAccessServer is the server API for TmpAccess service. All implementations must embed UnimplementedTmpAccessServer for forward compatibility.

type UnimplementedTmpAccessServer

type UnimplementedTmpAccessServer struct{}

UnimplementedTmpAccessServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedTmpAccessServer) GenerateTmpToken

type UnsafeTmpAccessServer

type UnsafeTmpAccessServer interface {
	// contains filtered or unexported methods
}

UnsafeTmpAccessServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TmpAccessServer will result in compilation errors.

Jump to